#ifndef MEMFD_H
#define MEMFD_H

#include <fcntl.h>

/* Linux-compatible defines */
#ifndef MFD_CLOEXEC
#define MFD_CLOEXEC         0x0001U
#define MFD_ALLOW_SEALING   0x0002U
#define MFD_HUGETLB         0x0004U
#define MFD_HUGE_SHIFT      26
#define MFD_HUGE_MASK       0x3f
#define MFD_HUGE_64KB       (16 << MFD_HUGE_SHIFT)
#define MFD_HUGE_2MB        (21 << MFD_HUGE_SHIFT)
#define MFD_HUGE_1GB        (30 << MFD_HUGE_SHIFT)
#endif

/* Sealing related defines */
#ifndef F_ADD_SEALS
#define F_LINUX_SPECIFIC_BASE   1024
#define F_ADD_SEALS             (F_LINUX_SPECIFIC_BASE + 9)
#define F_GET_SEALS             (F_LINUX_SPECIFIC_BASE + 10)

#define F_SEAL_SEAL             0x0001
#define F_SEAL_SHRINK           0x0002
#define F_SEAL_GROW             0x0004
#define F_SEAL_WRITE            0x0008
#define F_SEAL_FUTURE_WRITE     0x0010
#endif

#ifdef __cplusplus
extern "C" {
#endif

int memfd_create(const char *name, unsigned int flags);
int memfd_add_seals(int fd, unsigned int seals);
int memfd_get_seals(int fd);
int is_memfd(int fd);
const char *memfd_get_name(int fd);

#ifdef __cplusplus
}
#endif

#endif /* MEMFD_H */

